<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/TR/REC-html40">
    <xsl:output method="html" indent="no"/>
    <!--************************************************************************

  asanetwork stylesheet gas.xsl for emission test (gas)
  Copyright AxoNet Software GmbH 1999-2014

  17.09.2001   added OBD support, fixed missing result for CLOSED_LOOP_CTRL
  07.08.2003   removed OBD_ANALYSIS from output (for Dekra)
  28.04.2004   changed title and removed REPAIRED_DEFECTS from output
  29.04.2004   added a config section for top and bottom line
  22.09.2004   added support for Austria
  23.02.2007   added check for RESULT/TITLE length
  06.04.2009   suppress  unnexpected Bosch ESA output
  25.04.2014   allow logos with more width
  ****************************************************************************

  Include common used stylesheets

  ************************************************************************-->
    <xsl:include href="config/config.gas.xsl"/>
    <xsl:include href="config/address.xsl"/>
    <xsl:include href="config/language.xsl"/>
    <xsl:include href="include/htmlhead.xsl"/>
    <xsl:include href="include/util.xsl"/>
    <!--************************************************************************

  Process root element for emission test:
  Create HTML Body and main header, output address information from
  address.xsl, process RESULTHEADER (Date of test and
  equipment) and VEHICLE. Create HTML Table and output all SECTIONS.

  ************************************************************************-->
    <xsl:template match="/RESULTS">
        <body>
            <table border="0" cellpadding="0" cellspacing="1">
                <xsl:if test="$ShowTopLine = 1">
                    <tr>
                        <td colspan="{$Columns}">
                            <hr size="2"/>
                        </td>
                    </tr>
                </xsl:if>
                <tr>
                    <td align="left" colspan="{$Columns -3}">
                        <h3>
                            <xsl:if test="RESULT[@MODE='DEMO']">
                                <xsl:value-of select="$Demo"/>
                            </xsl:if>
                            <xsl:if test="($UseXmlTitle = 1) and string-length(RESULT/TITLE) > 25">
                                <xsl:value-of select="RESULT/TITLE"/>
                            </xsl:if>
                            <xsl:if test="($UseXmlTitle = 0) or (25 >= string-length(RESULT/TITLE))">
                                <xsl:choose>
                                    <xsl:when test="RESULT/@METHOD='GAS_OBD_CATALYST'"><xsl:value-of select="$ProtocolEmission1"/></xsl:when>
                                    <xsl:when test="RESULT/@METHOD='GAS_BIKE'"><xsl:value-of select="$ProtocolEmission1"/></xsl:when>
                                    <xsl:when test="RESULT/@METHOD='GAS_BIKE_CL_CATALYST'"><xsl:value-of select="$ProtocolEmission1"/></xsl:when>
                                    <xsl:otherwise><xsl:value-of select="$ProtocolEmission2"/></xsl:otherwise>
                                </xsl:choose>
                            </xsl:if>
                        </h3>
                        <xsl:apply-templates select="RESULT[1]/HEADER/END_TEST"/>
                    </td>
                    <td align="right" colspan="3">
                        <img src="{$Logo}"/>
                    </td>
                </tr>
                <tr>
                    <td colspan="{$Columns}">
                        <hr size="2"/>
                    </td>
                </tr>
                <xsl:call-template name="Address"/>
                <xsl:apply-templates select="RESULT[1]/HEADER"/>
                <xsl:apply-templates select="RESULTSHEADER/VEHICLE"/>
                <!-- table of measurements results -->
                <tr>
                    <td colspan="{$Columns}">
                        <hr size="2"/>
                    </td>
                </tr>
                <tr>
                    <th align="left" width="{$TitleW}">
                        <xsl:value-of select="$MeasResult"/>
                    </th>
                    <th align="left" width="{$UnitW}">
                        <xsl:value-of select="$Unit"/>
                    </th>
                    <th align="right" width="{$MeasW}">
                        <xsl:value-of select="$Min"/>
                    </th>
                    <th align="right" width="{$MeasW}">
                        <xsl:value-of select="$Max"/>
                    </th>
                    <th align="right" width="{$MeasW}">
                        <xsl:value-of select="$Measured"/>
                    </th>
                    <th align="right" width="{$ResW}">
                        <xsl:value-of select="$Result"/>
                    </th>
                </tr>
                <tr>
                    <td colspan="{$Columns}">
                        <hr size="2"/>
                    </td>
                </tr>
                <xsl:apply-templates select="RESULT/SECTION"/>
                <tr>
                    <td colspan="{$Columns}">
                        <hr size="2"/>
                    </td>
                </tr>
                <xsl:apply-templates select="RESULT/SUMMARY"/>
                <xsl:call-template name="Explain"/>
                <xsl:apply-templates select="RESULT/HEADER/CONTROL_NO" mode="Emission"/>
                <xsl:apply-templates select="RESULT/HEADER/OPERATOR" mode="Emission"/>
                <xsl:if test="$ShowBottomLine = 1">
                    <tr>
                        <td colspan="{$Columns}">
                            <hr size="2"/>
                        </td>
                    </tr>
                </xsl:if>
            </table>
        </body>
    </xsl:template>
    <!--************************************************************************
  
  Suppress OBD_ANALYSIS and REPAIRED_DEFECTS from output  
  
  ************************************************************************-->
    <xsl:template match="SECTION[@OBJECT='OBD_ANALYSIS']|SECTION[@OBJECT='REPAIRED_DEFECTS']|SECTION[@OBJECT='STANDARD']">
    </xsl:template>
    <!--************************************************************************
  
  Process SECTION or STEP
  Create new table row with title (span all columns except Ergebnis).
  If SECTION has SUMMARY or only one MEAS output this in column
  Result (except CONDITIONING); else output all MEAS or STEP; add a line at end
  
  ************************************************************************-->
    <xsl:template match="SECTION">
        <tr>
            <td colspan="{$Columns - 1}">
                <b>
                    <xsl:value-of select="TITLE"/>
                </b>
            </td>
            <td align="right">
                <!-- if we have only one MEAS and no other nodes, output result in summary column -->
                <xsl:if test="count(MEAS)=1 and count(SUMMARY)=0 and count(STEP)=0">
                    <b>
                        <xsl:apply-templates select="MEAS" mode="SINGLE"/>
                    </b>
                </xsl:if>
                <!-- if we have a summary, output result in summary column -->
                <xsl:if test="count(SUMMARY)=1">
                    <b>
                        <xsl:apply-templates select="SUMMARY" mode="SINGLE"/>
                    </b>
                </xsl:if>
            </td>
        </tr>
        <!-- expand all nodes if more than 1 MEAS or if CONDITIONING but not VISUAL_INSPECTION -->
        <xsl:if test="@OBJECT='CONDITIONING' or (@OBJECT!='VISUAL_INSPECTION' and count(MEAS)>1)">
            <xsl:apply-templates select="MEAS" mode="AU"/>
        </xsl:if>
        <!-- expand steps for CLOSED_LOOP_CTRL -->
        <xsl:if test="@OBJECT='CLOSED_LOOP_CTRL'">
            <xsl:apply-templates select="STEP[@OBJECT='BASE_VALUE']"/>
            <xsl:apply-templates select="STEP[@OBJECT='DISTURBANCE_ON']"/>
            <xsl:apply-templates select="STEP[@OBJECT='DISTURBANCE_OFF']"/>
        </xsl:if>
        <!-- expand steps for OBD -->
        <xsl:if test="@OBJECT='OBD_CTRL'">
            <xsl:apply-templates select="MEAS"/>
            <xsl:apply-templates select="STEP" mode="OBD"/>
        </xsl:if>
        <!-- add a line if not last element -->
        <xsl:if test="position() != last()">
            <tr>
                <td colspan="{$Columns}">
                    <hr size="1"/>
                </td>
            </tr>
        </xsl:if>
    </xsl:template>
    <!--********************************************************************

  Process STEP OBJECT=DISTURBANCE_ON/OFF:
  Output values together with STEP OBJECT=SETTLED_ON/OFF

  ********************************************************************-->
    <xsl:template match="STEP[@OBJECT='DISTURBANCE_ON']|STEP[@OBJECT='DISTURBANCE_OFF']">
        <tr>
            <td>
                <xsl:value-of select="TITLE"/>
            </td>
            <td colspan="{$Columns div 2 - 1}">
                <xsl:if test="@OBJECT='DISTURBANCE_ON'">
                    &#x03bb; = <xsl:value-of select="../STEP[@OBJECT='SETTLED_ON']/MEAS/VALUE"/>
                </xsl:if>
                <xsl:if test="@OBJECT='DISTURBANCE_OFF'">
                    &#x03bb; = <xsl:value-of select="../STEP[@OBJECT='SETTLED_OFF']/MEAS/VALUE"/>
                </xsl:if>
            </td>
            <td colspan="{$Columns div 2}" align="right">
                &#x0394; &#x03bb; = <xsl:value-of select="MEAS/VALUE[@RESULT]"/>
            </td>
        </tr>
    </xsl:template>
    <!--********************************************************************

  Process STEP OBJECT='BASE_VALUE':
  output SPEED, LAMBDA and Delta LAMBDA

  ********************************************************************-->
    <xsl:template match="STEP[@OBJECT='BASE_VALUE']">
        <xsl:apply-templates select="MEAS[@OBJECT='SPEED']"/>
        <tr>
            <td>
                <xsl:value-of select="TITLE"/>
            </td>
            <td colspan="{$Columns div 2 - 1}">
                &#x03bb; = <xsl:value-of select="MEAS[@OBJECT='LAMBDA' and not(VALUE/@TYPE='DELTA')]/VALUE"/>
            </td>
            <td colspan="{$Columns div 2}" align="right">
                &#x0394; &#x03bb; = <xsl:value-of select="MEAS[@OBJECT='LAMBDA' and VALUE/@TYPE='DELTA']/VALUE"/>
            </td>
        </tr>
    </xsl:template>
    <!--********************************************************************

  Process STEP for OBD: output MEAS

  ********************************************************************-->
    <xsl:template match="STEP" mode="OBD">
        <!-- empty line -->
        <tr>
            <td colspan="{$Columns}">
                <br/>
            </td>
        </tr>
        <!-- single line if only one MEAS -->
        <tr>
            <td colspan="{$Columns - 1}">
                <b>
                    <xsl:value-of select="TITLE"/>
                </b>
            </td>
            <td align="right">
                <xsl:if test="count(MEAS) = 1">
                    <xsl:apply-templates select="MEAS" mode="SINGLE"/>
                </xsl:if>
            </td>
        </tr>
        <xsl:if test="count(MEAS) > 1">
            <xsl:apply-templates select="MEAS"/>
        </xsl:if>
    </xsl:template>
    <!--************************************************************************

  Process MEAS in SECTION or SUMMARY, check if element is enabled in config

  ************************************************************************-->
    <xsl:template match="MEAS" mode="AU">
        <xsl:choose>
            <xsl:when test="@OBJECT='CO'">
                <xsl:if test="$PrintCO=1">
                    <xsl:apply-templates select="."/>
                </xsl:if>
            </xsl:when>
            <xsl:when test="@OBJECT='CO2'">
                <xsl:if test="$PrintCO2=1">
                    <xsl:apply-templates select="."/>
                </xsl:if>
            </xsl:when>
            <xsl:when test="@OBJECT='O2'">
                <xsl:if test="$PrintO2=1">
                    <xsl:apply-templates select="."/>
                </xsl:if>
            </xsl:when>
            <xsl:when test="@OBJECT='NO'">
                <xsl:if test="$PrintNO=1">
                    <xsl:apply-templates select="."/>
                </xsl:if>
            </xsl:when>
            <xsl:when test="@OBJECT='HC'">
                <xsl:if test="$PrintHC=1">
                    <xsl:apply-templates select="."/>
                </xsl:if>
            </xsl:when>
<!--
            <xsl:when test="@OBJECT='MODE'">
                <xsl:if test="$ShowMode=1">
                    <xsl:apply-templates select="."/>
                </xsl:if>
            </xsl:when>
            <xsl:when test="@OBJECT='PROBE'">
                <xsl:if test="$ShowProbe=1">
                    <xsl:apply-templates select="."/>
                </xsl:if>
            </xsl:when>
-->
            <xsl:otherwise>
                <xsl:apply-templates select="."/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
</xsl:stylesheet>
