<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/TR/REC-html40">
	<!--***********************************************************************

  UTIL.XSL common code used by all stylesheets

  Copyright AxoNet Software GmbH 1999-2015

  17.09.2001    added OBD support
  22.10.2001    Fixed problem if data doesn't start with axle 1 (in util.xsl)
  22.10.2001    added WORKSHOP support
  27.06.2002    added LOC_TITLE support  
  26.04.2004    modified explanations
  02.12.2008    added REGISTRATION_DATE
  02.02.2015    added support for Leitfaden 5
  ***************************************************************************
    
  Process attribute METHOD: output description of test method
    
  ************************************************************************-->
	<xsl:template match="@METHOD">
		<xsl:choose>
			<xsl:when test=".='GAS_BIKE'">
				<xsl:value-of select="$GAS_BIKE"/>
			</xsl:when>
			<xsl:when test=".='GAS_BIKE_CL_CATALYST'">
				<xsl:value-of select="$GAS_BIKE_CL_CATALYST"/>
			</xsl:when>
			<xsl:when test=".='GAS_OL_CATALYST'">
				<xsl:value-of select="$GAS_OL_CATALYST"/>
			</xsl:when>
			<xsl:when test=".='GAS_CL_CATALYST'">
				<xsl:value-of select="$GAS_CL_CATALYST"/>
			</xsl:when>
			<xsl:when test=".='GAS_OBD_CATALYST'">
				<xsl:value-of select="$GAS_OBD_CATALYST"/>
			</xsl:when>
			<xsl:when test=".='GAS'">
				<xsl:value-of select="$GAS"/>
			</xsl:when>
			<xsl:when test=".='SMOKE'">
				<xsl:value-of select="$SMOKE"/>
			</xsl:when>
			<xsl:when test=".='SMOKE_TURBO'">
				<xsl:value-of select="$SMOKE_TURBO"/>
			</xsl:when>
			<xsl:when test=".='SMOKE_OBD'">
				<xsl:value-of select="$SMOKE_OBD"/>
			</xsl:when>
			<xsl:when test=".='QUICK'">
				<xsl:value-of select="$QUICK"/>
			</xsl:when>
			<xsl:when test=".='STANDARD'">
				<xsl:value-of select="$STANDARD"/>
			</xsl:when>
			<xsl:when test=".='MANUFACTURER_SPECIFIC'">
				<xsl:value-of select="$MANUFACTURER_SPECIFIC"/>
			</xsl:when>
			<xsl:when test=".='ACCIDENT_VEHICLE'">
				<xsl:value-of select="$ACCIDENT_VEHICLE"/>
			</xsl:when>
			<xsl:when test=".='FOURWD'">
				<xsl:value-of select="$FOURWD"/>
			</xsl:when>
			<xsl:when test=".='DETAILED'">
				<xsl:value-of select="$DETAILED"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--***********************************************************************

  Process attribute UNIT: output unit shotcut

  ************************************************************************-->
	<xsl:template match="@UNIT">
		<xsl:choose>
			<xsl:when test="contains(string(.), '64')"/>
			<xsl:when test=".='1'"/>
			<xsl:when test=".='rpm'">
				<xsl:value-of select="$rpm"/>
			</xsl:when>
			<xsl:when test=".='degC'">
				<xsl:value-of select="$degC"/>
			</xsl:when>
			<xsl:when test=".='degCS'">
				<xsl:value-of select="$degCS"/>
			</xsl:when>
			<xsl:when test=".='deg'">
				<xsl:value-of select="$deg"/>
			</xsl:when>
			<xsl:when test=".='deg60'">
				<xsl:value-of select="$deg60"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--***********************************************************************

  Process attribute RESULT: output shortcut of result, optional use color

  ************************************************************************-->
	<xsl:template match="@RESULT">
		<xsl:choose>
			<xsl:when test=".='0'"/>
			<xsl:when test=".='1'">
				<xsl:if test="$UseResColor = 1">
					<font color="{$GREEN}">
						<xsl:value-of select="$RESULTle1"/>
					</font>
				</xsl:if>
				<xsl:if test="$UseResColor = 0">
					<xsl:value-of select="$RESULTle1"/>
				</xsl:if>
			</xsl:when>
			<xsl:when test=".>'1'">
				<xsl:if test="$UseResColor = 1">
					<font color="{$RED}">
						<xsl:value-of select="$RESULTgt1"/>
					</font>
				</xsl:if>
				<xsl:if test="$UseResColor = 0">
					<xsl:value-of select="$RESULTgt1"/>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise/>
		</xsl:choose>
	</xsl:template>
	<!--***********************************************************************

  Process HEADER: Output table of equipment

  ************************************************************************-->
	<xsl:template match="HEADER">
		<xsl:if test="$ShowDevice = 1">
			<tr>
				<td colspan="{round($Columns div 3)}">
					<b>
						<xsl:value-of select="$Device"/>
					</b>
				</td>
				<td colspan="{round($Columns *2 div 3)}">
					<b>
						<xsl:value-of select="$Version"/>
					</b>
				</td>
			</tr>
			<xsl:for-each select="//EQUIPMENT">
				<xsl:apply-templates select="."/>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************

  Process CONTROL_NO:

  ************************************************************************-->
	<xsl:template match="CONTROL_NO" mode="Emission">
		<xsl:if test="$ShowControlNo = 1">
			<tr>
				<td>
					<b>
						<xsl:value-of select="$CONTROL_NO"/>
					</b>
				</td>
				<td colspan="{$Columns - 1}" align="left">
					<xsl:value-of select="."/>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************
 
  Process attribute SOURCE: replace 'HAND' with #
 
  ************************************************************************-->
	<xsl:template match="@SOURCE">
		<xsl:if test=". = 'HAND'">
            #
        </xsl:if>
	</xsl:template>
	<!--***********************************************************************
 
  Process END_TEST
 
  ************************************************************************-->
	<xsl:template match="END_TEST">
		<xsl:value-of select="$Date"/>&#160;<xsl:value-of select="."/>
	</xsl:template>
	<!--***********************************************************************
 
  Process PROTOCOL_NO
 
  ************************************************************************-->
	<xsl:template match="PROTOCOL_NO">
		<xsl:value-of select="$PROTOCOL_NO"/>&#160;<xsl:value-of select="."/>
	</xsl:template>
	<!--***********************************************************************
 
  Process CONTROL_NO
 
  ************************************************************************-->
	<xsl:template match="CONTROL_NO">
		<xsl:value-of select="$CONTROL_NO2"/>&#160;<xsl:value-of select="."/>
	</xsl:template>
	<!--***********************************************************************
 
  Process OPERATOR, add empty space and stamp/signature field
 
  ************************************************************************-->
	<xsl:template match="OPERATOR" mode="Emission">
		<xsl:if test="$ShowOperator = 1">
			<tr>
				<td>
					<b>
						<xsl:value-of select="$OPERATOR"/>
					</b>
				</td>
				<td colspan="{$Columns - 1}" align="left">
					<xsl:value-of select="NAME"/>
				</td>
			</tr>
		</xsl:if>
		<tr valign="bottom">
			<td height="40" colspan="{round($Columns div 2)}">
				<b>
					<xsl:value-of select="$Signature"/>
				</b>
			</td>
			<td colspan="{round($Columns div 2)}">
				<b>
					<xsl:value-of select="$Stamp"/>
				</b>
			</td>
		</tr>
	</xsl:template>
	<!--***********************************************************************
 
  Process OPERATOR, output name and number
 
  ************************************************************************-->
	<xsl:template match="OPERATOR">
		<xsl:if test="$ShowOperator = 1">
			<xsl:if test="NAME != '' or OP_NO != ''">
				<tr>
					<td colspan="{round($Columns div 3)}">
						<xsl:value-of select="$OPERATOR2"/>
					</td>
					<td colspan="{round($Columns * 2 div 3)}">
						<xsl:value-of select="NAME"/>
            &#160;
            <xsl:value-of select="OP_NO"/>
					</td>
				</tr>
				<tr>
					<td colspan="{$Columns}">
						<br/>
					</td>
				</tr>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************

  Process REF, output title, manufacturer, model and software version

  ************************************************************************-->
	<xsl:template match="REF">
		<tr>
			<td colspan="{$Columns}">
				<b>
					<xsl:value-of select="$Reference"/>
				</b>
			</td>
		</tr>
		<tr>
			<td colspan="{round($Columns div 3)}">
				<xsl:value-of select="TITLE"/>
        &#160;
        <xsl:value-of select="END_TEST"/>
			</td>
			<td colspan="{round($Columns * 2 div 3)}">
				<xsl:value-of select="$PROTOCOL_NO"/>
				<xsl:value-of select="PROTOCOL_NO"/>&#160;/&#160;
        <xsl:value-of select="$CONTROL_NO2"/>
				<xsl:value-of select="CONTROL_NO"/>
			</td>
		</tr>
		<tr>
			<td colspan="{round($Columns div 3)}">
				<xsl:value-of select="$OPERATOR2"/>
        &#160;
        <xsl:value-of select="OPERATOR/NAME"/>
			</td>
			<td colspan="{round($Columns * 2 div 3)}">
				<xsl:value-of select="OPERATOR/PERMISSION/ID1"/>
			</td>
		</tr>
	</xsl:template>
	<!--***********************************************************************

  Process EQUIPMENT, output title, manufacturer, model and software version

  ************************************************************************-->
	<xsl:template match="EQUIPMENT">
		<tr>
			<td colspan="{round($Columns div 3)}">
				<xsl:value-of select="TITLE"/>&#160;<xsl:value-of select="MANUFACTURER"/>&#160;<xsl:value-of select="MODEL"/>
			</td>
			<td colspan="{round($Columns * 2 div 3)}">
				<xsl:value-of select="VERSION"/>
			</td>
		</tr>
		<xsl:if test="DATA_RELEASE">
			<tr>
				<td colspan="{round($Columns div 3)}">
					<xsl:value-of select="$Nominaldata"/>
				</td>
				<td colspan="{round($Columns * 2 div 3)}">
					<xsl:value-of select="DATA_RELEASE"/>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************

  Process VEHICLE, output METHOD if present and vehicle IDENT and DATA

  ************************************************************************-->
	<xsl:template match="VEHICLE">
		<tr>
			<td colspan="{$Columns}">
				<br/>
			</td>
		</tr>
		<xsl:if test="//RESULT/@METHOD != ''">
			<tr>
				<td colspan="{round($Columns div 3)}">
					<b>
						<xsl:value-of select="$Program"/>:</b>
				</td>
				<td colspan="{round($Columns * 2 div 3)}">
					<b>
						<xsl:choose>
							<xsl:when test="//RESULT/@METHOD_TITLE != ''">
								<xsl:apply-templates select="//RESULT/@METHOD_TITLE"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:apply-templates select="//RESULT/@METHOD"/>
							</xsl:otherwise>
						</xsl:choose>
					</b>
				</td>
			</tr>
			<tr>
				<td colspan="{$Columns}">
					<br/>
				</td>
			</tr>
		</xsl:if>
		<tr>
			<td colspan="{round($Columns div 3)}">
				<b>
					<xsl:value-of select="$Vehicle"/>
				</b>
			</td>
			<td colspan="{round($Columns * 2 div 3)}">
				<xsl:value-of select="IDENT/MANUFACTURER"/>
                &#160;
                <xsl:value-of select="IDENT/MODEL"/>
			</td>
		</tr>
		<xsl:apply-templates select="IDENT"/>
		<xsl:apply-templates select="DATA"/>
	</xsl:template>
	<!--***********************************************************************

  Process vehicle IDENT data

  ************************************************************************-->
	<xsl:template match="IDENT">
		<xsl:if test="$ShowKBA=1">
			<xsl:if test="EMISSIONCODE">
			<tr>
				<td colspan="{round($Columns div 3)}">
					<xsl:value-of select="$Key1"/>:</td>
				<td colspan="{round($Columns * 2 div 3)}">
					<xsl:value-of select="EMISSIONCODE"/>
				</td>
			</tr>
			</xsl:if>
			<xsl:if test="NO_EMISSIONCODE">
			<tr>
				<td colspan="{round($Columns div 3)}">
					<xsl:value-of select="$Key1"/>:</td>
				<td colspan="{round($Columns * 2 div 3)}">
					<xsl:value-of select="NO_EMISSIONCODE"/>
				</td>
			</tr>
			</xsl:if>
			<tr>
				<td colspan="{round($Columns div 3)}">
					<xsl:value-of select="$Key2"/>:</td>
				<td colspan="{round($Columns * 2 div 3)}">
					<xsl:value-of select="KEY2"/>
				</td>
			</tr>
			<tr>
				<td colspan="{round($Columns div 3)}">
					<xsl:value-of select="$Key3"/>:</td>
				<td colspan="{round($Columns * 2 div 3)}">
					<xsl:value-of select="KEY3"/>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="$ShowEngineCode=1">
			<tr>
				<td colspan="{round($Columns div 3)}">
					<xsl:value-of select="$ENGINECODE"/>:</td>
				<td colspan="{round($Columns * 2 div 3)}">
					<xsl:value-of select="ENGINECODE"/>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="REGISTRATION">
		<tr>
			<td colspan="{round($Columns div 3)}">
				<xsl:value-of select="$Registration"/>:</td>
			<td colspan="{round($Columns * 2 div 3)}">
				<xsl:value-of select="REGISTRATION"/>
			</td>
		</tr>
		</xsl:if>
		<xsl:if test="NOT_REGISTERED">
		<tr>
			<td colspan="{round($Columns div 3)}">
				<xsl:value-of select="$Registration"/>:</td>
			<td colspan="{round($Columns * 2 div 3)}">
				<xsl:value-of select="NOT_REGISTERED"/>
			</td>
		</tr>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="VIN1">
				<tr>
					<td colspan="{round($Columns div 3)}">
						<xsl:value-of select="$Vin"/>:
					</td>
					<td colspan="{round($Columns * 2 div 3)}">
						<xsl:value-of select="VIN"/>
						<xsl:apply-templates select="VIN/@SOURCE"/>
					</td>
				</tr>
				<tr>
					<td colspan="{round($Columns div 3)}"/>
					<td colspan="{round($Columns * 2 div 3)}">
						<xsl:value-of select="VIN1"/>
					</td>
				</tr>
				<xsl:if test="VIN2">
					<tr>
						<td colspan="{round($Columns div 3)}"/>
						<td colspan="{round($Columns * 2 div 3)}">
							<xsl:value-of select="VIN2"/>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="VIN3">
					<tr>
						<td colspan="{round($Columns div 3)}"/>
						<td colspan="{round($Columns * 2 div 3)}">
							<xsl:value-of select="VIN3"/>
						</td>
					</tr>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<tr>
					<td colspan="{round($Columns div 3)}">
						<xsl:value-of select="$Vin"/>:</td>
					<td colspan="{round($Columns * 2 div 3)}">
						<xsl:value-of select="VIN"/>
					</td>
				</tr>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="PRODUCTIONDATE">
			<xsl:if test="not(../DATA/REGISTRATION_DATE)">
				<tr>
					<td colspan="{round($Columns div 3)}">
						<xsl:value-of select="$REGISTRATION_DATE"/>:</td>
					<td colspan="{round($Columns * 2 div 3)}">
						<xsl:value-of select="PRODUCTIONDATE"/>
					</td>
				</tr>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************

  Process vehicle DATA

  ************************************************************************-->
	<xsl:template match="DATA">
		<xsl:if test="REGISTRATION_DATE">
			<tr>
				<td colspan="{round($Columns div 3)}">
					<xsl:value-of select="$REGISTRATION_DATE"/>:</td>
				<td colspan="{round($Columns * 2 div 3)}">
					<xsl:value-of select="REGISTRATION_DATE"/>
				</td>
			</tr>
		</xsl:if>
		<tr>
			<td colspan="{round($Columns div 3)}">
				<xsl:value-of select="$Odometer"/>:</td>
			<td colspan="{round($Columns * 2 div 3)}">
				<xsl:value-of select="ODOMETER"/>
			</td>
		</tr>
	</xsl:template>
	<!--***********************************************************************

  Named template called for address output

  ************************************************************************-->
	<xsl:template name="Address">
		<!-- use data from XML -->
		<xsl:if test="((count(/RESULTS/RESULTSHEADER/WORKSHOP) = 1) and (string-length(/RESULTS/RESULTSHEADER/WORKSHOP/NAME) > 0))">
			<tr>
				<td colspan="{round($Columns div 3)}">
					<b>
						<xsl:value-of select="/RESULTS/RESULTSHEADER/WORKSHOP/NAME"/>
					</b>
				</td>
				<td colspan="{round($Columns * 2 div 3)}" align="right">
					<b>
						<xsl:value-of select="/RESULTS/RESULTSHEADER/WORKSHOP/NAME2"/>
					</b>
				</td>
			</tr>
			<tr>
				<td colspan="{round($Columns div 3)}">
					<b>
						<xsl:value-of select="/RESULTS/RESULTSHEADER/WORKSHOP/ADDRESS"/>
					</b>
				</td>
				<td colspan="{round($Columns * 2 div 3)}" align="right">
					<b>Tel.: <xsl:value-of select="/RESULTS/RESULTSHEADER/WORKSHOP/TEL"/>
					</b>
				</td>
			</tr>
			<tr>
				<td colspan="{round($Columns div 3)}">
					<b>
						<xsl:value-of select="/RESULTS/RESULTSHEADER/WORKSHOP/ZIP"/>
            &#160;
            <xsl:value-of select="/RESULTS/RESULTSHEADER/WORKSHOP/CITY"/>
					</b>
				</td>
				<td colspan="{round($Columns * 2 div 3)}" align="right">
					<b>Fax: <xsl:value-of select="/RESULTS/RESULTSHEADER/WORKSHOP/FAX"/>
					</b>
				</td>
			</tr>
			<tr>
				<td colspan="{$Columns}">
					<hr size="2"/>
				</td>
			</tr>
		</xsl:if>
		<!-- use fixed data from included address.xsl (defined in viewer) -->
		<xsl:if test="((count(/RESULTS/RESULTSHEADER/WORKSHOP) = 0) or (string-length(/RESULTS/RESULTSHEADER/WORKSHOP/NAME) = 0))">
			<tr>
				<td colspan="{round($Columns div 3)}">
					<b>
						<xsl:value-of select="$Address1"/>
					</b>
				</td>
				<td colspan="{round($Columns * 2 div 3)}" align="right">
					<b>
						<xsl:value-of select="$Address2"/>
					</b>
				</td>
			</tr>
			<tr>
				<td colspan="{round($Columns div 3)}">
					<b>
						<xsl:value-of select="$Address3"/>
					</b>
				</td>
				<td colspan="{round($Columns * 2 div 3)}" align="right">
					<b>Tel.:<xsl:value-of select="$Phone"/>
					</b>
				</td>
			</tr>
			<tr>
				<td colspan="{round($Columns div 3)}">
					<b>
						<xsl:value-of select="$Address4"/>
					</b>
				</td>
				<td colspan="{round($Columns * 2 div 3)}" align="right">
					<b>Fax:<xsl:value-of select="$Fax"/>
					</b>
				</td>
			</tr>
			<tr>
				<td colspan="{$Columns}">
					<hr size="2"/>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************

  Process MEAS: check for VALUE TYPE='DISP' and apply correct VALUE
  always output details
  
  ************************************************************************-->
	<xsl:template match="MEAS">
		<xsl:choose>
			<xsl:when test="count(VALUE[@TYPE='DISP']) > 0">
				<xsl:apply-templates select="VALUE[@TYPE='DISP']"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="VALUE"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--***********************************************************************
	
  Process MEAS: if single MEAS don't create new row, only put out VALUE/RESULT
  else use default processing
  
  ************************************************************************-->
	<xsl:template match="MEAS" mode="SINGLE">
		<xsl:choose>
			<!-- check if we have only one MEAS without other STEPs -->
			<xsl:when test="count(../MEAS) = 1 and count(../STEP) = 0">
				<xsl:apply-templates select="VALUE/@SOURCE"/>
				<xsl:apply-templates select="VALUE/@RESULT"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- use default -->
				<xsl:apply-templates select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--***********************************************************************
  
  Process VALUE if TYPE is not DISP (default)
  
  ************************************************************************-->
	<xsl:template match="VALUE">
		<xsl:if test="../@OBJECT='IMAGE'">
			<tr>
				<td>
					<xsl:value-of select="../TITLE"/>
				</td>
				<td align="center" colspan="{$Columns - 1}">
					<xsl:call-template name="DoImage"/>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="../@OBJECT!='IMAGE'">
			<tr>
				<td>
					<xsl:value-of select="../TITLE"/>&#160;
                    <xsl:value-of select="../@LOC_TITLE"/>
				</td>
				<td>
					<xsl:apply-templates select="@UNIT"/>
				</td>
				<td align="right">
					<xsl:value-of select="@NOMINAL"/>
					<xsl:value-of select="@LOWLIM1"/>
				</td>
				<td align="right">
					<xsl:value-of select="@NOMINAL"/>
					<xsl:value-of select="@HIGHLIM1"/>
				</td>
				<td align="right">
					<xsl:call-template name="DoValue"/>
				</td>
				<td align="right">
					<xsl:apply-templates select="@SOURCE"/>
					<xsl:apply-templates select="@RESULT"/>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************
  
  Process VALUE if TYPE is DISP
  
  ************************************************************************-->
	<xsl:template match="VALUE[@TYPE='DISP']">
		<tr>
			<td>
				<xsl:value-of select="../TITLE"/>&#160;
        <xsl:value-of select="../@LOC_TITLE"/>
			</td>
			<td>
				<xsl:apply-templates select="@UNIT"/>
			</td>
			<td align="right">
				<xsl:value-of select="@NOMINALDISP"/>
				<xsl:value-of select="@LOWDISP"/>
			</td>
			<td align="right">
				<xsl:value-of select="@NOMINALDISP"/>
				<xsl:value-of select="@HIGHDISP"/>
			</td>
			<td align="right">
				<xsl:call-template name="DoValue"/>
			</td>
			<td align="right">
				<xsl:apply-templates select="@SOURCE"/>
				<xsl:apply-templates select="@RESULT"/>
			</td>
		</tr>
	</xsl:template>
	<!--***********************************************************************
  
  Named template called to output an image
  
  ************************************************************************-->
	<xsl:template name="DoImage">
		<xsl:if test="count(@IMAGE) = 0">
			<IMG>
				<xsl:attribute name="src"><xsl:value-of select="."/></xsl:attribute>
			</IMG>
		</xsl:if>
		<xsl:if test="count(@IMAGE) != 0">
			<xsl:value-of select="$Picture"/>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************
  
  Named template called to output one VALUE, optional using color
  
  ************************************************************************-->
	<xsl:template name="DoValue">
		<xsl:if test="$UseMeasColor = 1">
			<xsl:if test="@RESULT > 1">
				<font color="{$RED}">
					<xsl:value-of select="."/>
				</font>
			</xsl:if>
			<xsl:if test="@RESULT = 1">
				<font color="{$GREEN}">
					<xsl:value-of select="."/>
				</font>
			</xsl:if>
			<xsl:if test="string(@RESULT) = 0">
				<xsl:value-of select="."/>
			</xsl:if>
			<xsl:if test="count(@RESULT) = 0">
				<xsl:value-of select="."/>
			</xsl:if>
		</xsl:if>
		<xsl:if test="$UseMeasColor = 0">
			<xsl:value-of select="."/>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************
  
  Process MEAS in SUMMARY, only show values if more than one 
  
  ************************************************************************-->
	<xsl:template match="SUMMARY">
		<tr>
			<td colspan="{$Columns}">
				<b>
					<xsl:value-of select="TITLE"/>
				</b>
			</td>
		</tr>
		<xsl:apply-templates select="MEAS"/>
	</xsl:template>
	<!--***********************************************************************
  
  Process MEAS in SUMMARY as result for single element
  If only one MEAS put in existing row else create new row 
  
  ************************************************************************-->
	<xsl:template match="SUMMARY" mode="SINGLE">
		<xsl:apply-templates select="MEAS" mode="SINGLE"/>
	</xsl:template>
	<!--***********************************************************************
  
  Process RESULT/SUMMARY: create table title and output MEAS
  
  ************************************************************************-->
	<xsl:template name="Explain">
		<tr>
			<td colspan="{$Columns}">
				<hr size="2"/>
			</td>
		</tr>
		<tr>
			<td colspan="1">
				<b>
					<xsl:value-of select="$Explanation"/>
				</b>
			</td>
			<td colspan="{$Columns}-1">
				<xsl:value-of select="$Hand"/>
			</td>
		</tr>
		<tr>
			<td colspan="{$Columns}">
                &#160;
            </td>
		</tr>
	</xsl:template>
	<!--***********************************************************************
  
  Process RESULT/SUMMARY: create table title and output MEAS
  
  ************************************************************************-->
	<xsl:template match="RESULT/SUMMARY|/RESULTS/SUMMARY">
		<tr>
			<td colspan="{$Columns}">
				<b>
					<xsl:value-of select="TITLE"/>
				</b>
			</td>
		</tr>
		<xsl:apply-templates select="STEP|MEAS"/>
	</xsl:template>
	<xsl:template match="RESULT/SUMMARY/STEP|/RESULTS/SUMMARY/STEP">
		<tr>
			<td colspan="{$Columns}">
				<hr size="1"/>
			</td>
		</tr>
		<xsl:apply-templates select="MEAS"/>
	</xsl:template>
	<!--***********************************************************************
  
  Process MEAS of RESULT(S)/SUMMARY: create new table row and place output
  in Result column
  
  ************************************************************************-->
	<xsl:template match="RESULT/SUMMARY/MEAS|/RESULTS/SUMMARY/MEAS">
		<xsl:if test="@OBJECT != 'NOTES'">
			<tr>
				<td>
					<xsl:value-of select="TITLE"/>
				</td>
				<td colspan="{$Columns -1}">
					<b><xsl:apply-templates select="VALUE"/></b>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="@OBJECT = 'NOTES'">
			<tr>
				<td align="left" valign="top" colspan="1">
					<xsl:value-of select="TITLE"/>
				</td>
				<td align="left" valign="top" colspan="{$Columns - 1}">
					<xsl:value-of select="VALUE"/>
				</td>
			</tr>
		</xsl:if>		
	</xsl:template>
	<!--***********************************************************************
  
  Process VALUE of RESULT/SUMMARY/MEAS: place all output in one column
  
  ************************************************************************-->
	<xsl:template match="RESULT/SUMMARY/MEAS/VALUE|/RESULTS/SUMMARY/MEAS/VALUE">
		<xsl:if test="../@OBJECT = 'IMAGE'">
			<xsl:call-template name="DoImage"/>
		</xsl:if>
		<xsl:if test="../@OBJECT != 'IMAGE'">
			<xsl:value-of select="."/>	
		</xsl:if>
		<xsl:if test="position() != last()">, &#160;</xsl:if>
	</xsl:template>
	<!--***********************************************************************

  Calculate number of columns = number of axle + 2

  ************************************************************************-->
	<xsl:template name="CalcColumns">
		<xsl:if test="number($Axle) &lt;= 2">4</xsl:if>
		<xsl:if test="number($Axle) > 2">
			<xsl:value-of select="number($Axle) + 2"/>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************

  create table header, calculate number of rows and width

  ************************************************************************-->
	<xsl:template name="SetupHeader">
		<xsl:param name="cnt" select="1"/>
		<!--	<xsl:message><xsl:value-of select="$Axle"/></xsl:message> -->
		<xsl:if test="$Axle >= $cnt">
			<xsl:choose>
				<xsl:when test="number($Axle) &lt;= 4">
					<th align="right" width="{$MeasW*2}">
						<xsl:value-of select="$AXLE"/>
						<xsl:text/>
						<xsl:value-of select="$cnt"/>
					</th>
				</xsl:when>
				<xsl:when test="number($Axle)  > 7">
					<th align="center" width="{$MeasW}">
						<xsl:value-of select="$AXLE"/>
						<xsl:text/>
						<xsl:value-of select="$cnt"/>
					</th>
				</xsl:when>
				<xsl:otherwise>
					<th align="right" width="{$MeasW*1.5}">
						<xsl:value-of select="$AXLE"/>
						<xsl:text/>
						<xsl:value-of select="$cnt"/>
					</th>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:call-template name="SetupHeader">
				<xsl:with-param name="cnt" select="$cnt + 1"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************

  Process DoSection
  Create table row and call DoSection to fill the row with the specified value
  
  ************************************************************************-->
	<xsl:template name="DoSection">
		<xsl:param name="n" select="1"/>
		<xsl:param name="Meas"/>
		<xsl:if test="SECTION/MEAS[@OBJECT=$Meas][$n]">
			<tr>
				<td>
					<xsl:value-of select="SECTION/MEAS[@OBJECT=$Meas][$n]/TITLE"/>&#160;
          <xsl:value-of select="SECTION/MEAS[@OBJECT=$Meas][$n]/@LOC_TITLE"/>
				</td>
				<td>
					<xsl:value-of select="SECTION/MEAS[@OBJECT=$Meas][$n]/VALUE/@UNIT"/>
				</td>
				<xsl:for-each select="SECTION">
					<td align="right">
						<xsl:apply-templates select="MEAS[@OBJECT=$Meas][$n]/VALUE" mode="AXLE"/>
						<xsl:apply-templates select="MEAS[@OBJECT=$Meas][$n]/VALUE/@SOURCE"/>
					</td>
				</xsl:for-each>
			</tr>
		</xsl:if>
		<xsl:if test="SECTION/MEAS[@OBJECT=$Meas][$n+1]">
			<xsl:call-template name="DoSection">
				<xsl:with-param name="n" select="$n+1"/>
				<xsl:with-param name="Meas" select="$Meas"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************

  Process DoStep
  Create table row and call DoStep to fill the row with the specified value
  
  ************************************************************************-->
	<xsl:template name="DoStep">
		<xsl:param name="n" select="1"/>
		<xsl:param name="Step"/>
		<xsl:param name="Meas"/>
		<xsl:if test="SECTION/STEP[@OBJECT=$Step]/MEAS[@OBJECT=$Meas][$n]">
			<tr>
				<td>
					<xsl:value-of select="SECTION/STEP[@OBJECT=$Step]/MEAS[@OBJECT=$Meas][$n]/TITLE"/>&#160;
          <xsl:value-of select="SECTION/STEP[@OBJECT=$Step]/MEAS[@OBJECT=$Meas][$n]/@LOC_TITLE"/>
				</td>
				<td>
					<xsl:value-of select="SECTION/STEP[@OBJECT=$Step]/MEAS[@OBJECT=$Meas][$n]/VALUE/@UNIT"/>
				</td>
				<xsl:for-each select="SECTION">
					<td align="right">
						<xsl:apply-templates select="STEP[@OBJECT=$Step]/MEAS[@OBJECT=$Meas][$n]/VALUE" mode="AXLE"/>
						<xsl:apply-templates select="STEP[@OBJECT=$Step]/MEAS[@OBJECT=$Meas][$n]/VALUE/@SOURCE"/>
					</td>
				</xsl:for-each>
			</tr>
		</xsl:if>
		<xsl:if test="SECTION/STEP[@OBJECT=$Step]/MEAS[@OBJECT=$Meas][$n+1]">
			<xsl:call-template name="DoStep">
				<xsl:with-param name="n" select="$n+1"/>
				<xsl:with-param name="Step" select="$Step"/>
				<xsl:with-param name="Meas" select="$Meas"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!--***********************************************************************
  
  Process VALUE if TYPE is not DISP (default)
 
 ************************************************************************-->
	<xsl:template match="VALUE" mode="AXLE">
		<xsl:call-template name="DoValue"/>
	</xsl:template>
	<!--***********************************************************************
 
  Process VALUE if TYPE is DISP, mode = AXLE
 
  ************************************************************************-->
	<xsl:template match="VALUE[@TYPE='DISP']" mode="AXLE">
		<xsl:call-template name="DoValue"/>
	</xsl:template>
</xsl:stylesheet>
