<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/TR/REC-html40">
    <xsl:output method="html" indent="no"/>
    <!--************************************************************************

  asanetwork stylesheet smoke.xsl for emission test (smoke)
  Copyright AxoNet Software GmbH 1999-2014
    
  17.09.2001   placed units for gas blasts on a separate row
  27.04.2004   changed title
  29.04.2004   added a config section for top and bottom line
  22.09.2004   added support for Austria
  28.10.2005   added support for SMOKE_ODB
  23.02.2007   added check for RESULT/TITLE length
  25.04.2014   allow logos with more width
  ****************************************************************************

  Include common stylesheets and configuration

  ************************************************************************-->
    <xsl:include href="config/config.smoke.xsl"/>
    <xsl:include href="config/address.xsl"/>
    <xsl:include href="config/language.xsl"/>
    <xsl:include href="include/htmlhead.xsl"/>
    <xsl:include href="include/util.xsl"/>
    <!--************************************************************************

  Process root element for emission test:
  Create HTML Body and main header, output address information from
  address.xsl, process RESULTHEADER (Date of test and
  equipment) and VEHICLE. Create HTML Table and output all SECTIONS.

  ************************************************************************-->
    <xsl:template match="/RESULTS">
        <body>
            <table border="0" cellpadding="0" cellspacing="1">
                <xsl:if test="$ShowTopLine = 1">
                    <tr>
                        <td colspan="{$Columns}">
                            <hr size="2"/>
                        </td>
                    </tr>
                </xsl:if>
                <tr>
                    <td align="left" colspan="{$Columns -3}">
                        <h3>
                            <xsl:if test="RESULT[@MODE='DEMO']">
                                <xsl:value-of select="$Demo"/>
                            </xsl:if>
                            <xsl:if test="($UseXmlTitle = 1) and string-length(RESULT/TITLE) > 25">
                                <xsl:value-of select="RESULT/TITLE"/>
                            </xsl:if>
                            <xsl:if test="($UseXmlTitle = 0) or (25 >= string-length(RESULT/TITLE))">
                                <xsl:choose>
                                    <xsl:when test="RESULT/@METHOD='SMOKE_OBD'"><xsl:value-of select="$ProtocolEmission1"/></xsl:when>
                                    <xsl:otherwise><xsl:value-of select="$ProtocolEmission2"/></xsl:otherwise>
                                </xsl:choose>
                            </xsl:if>
                        </h3>
                        <xsl:apply-templates select="RESULT[1]/HEADER/END_TEST"/>
                    </td>
                    <td align="right" colspan="3">
                        <img src="{$Logo}"/>
                    </td>
                </tr>
                <tr>
                    <td colspan="{$Columns}">
                        <hr size="2"/>
                    </td>
                </tr>
                <xsl:call-template name="Address"/>
                <xsl:apply-templates select="RESULT[1]/HEADER"/>
                <xsl:apply-templates select="RESULTSHEADER/VEHICLE"/>
                <!-- table of measurements results -->
                <tr>
                    <td colspan="{$Columns}">
                        <hr size="2"/>
                    </td>
                </tr>
                <tr>
                    <th align="left" width="{$TitleW}">
                        <xsl:value-of select="$MeasResult"/>
                    </th>
                    <th align="left" width="{$UnitW}">
                        <xsl:value-of select="$Unit"/>
                    </th>
                    <th align="right" width="{$MeasW}">
                        <xsl:value-of select="$Min"/>
                    </th>
                    <th align="right" width="{$MeasW}">
                        <xsl:value-of select="$Max"/>
                    </th>
                    <th align="right" width="{$MeasW}">
                        <xsl:value-of select="$Measured"/>
                    </th>
                    <th align="right" width="{$ResW}">
                        <xsl:value-of select="$Result"/>
                    </th>
                </tr>
                <tr>
                    <td colspan="{$Columns}">
                        <hr size="2"/>
                    </td>
                </tr>
                <xsl:apply-templates select="RESULT/SECTION"/>
                <tr>
                    <td colspan="{$Columns}">
                        <hr size="2"/>
                    </td>
                </tr>
                <xsl:apply-templates select="RESULT/SUMMARY"/>
                <xsl:call-template name="Explain"/>
                <xsl:apply-templates select="RESULT/HEADER/CONTROL_NO" mode="Emission"/>
                <xsl:apply-templates select="RESULT/HEADER/OPERATOR" mode="Emission"/>
                <xsl:if test="$ShowBottomLine = 1">
                    <tr>
                        <td colspan="{$Columns}">
                            <hr size="2"/>
                        </td>
                    </tr>
                </xsl:if>
            </table>
        </body>
    </xsl:template>
    <!--************************************************************************

  Process SECTION
  Create new table row with title (span all columns except Ergebnis).
  If SECTION has SUMMARY or only one MEAS output this in column
  Result (except CONDITIONING); else output all MEAS or STEP;
  add a line at end

  ************************************************************************-->
    <xsl:template match="SECTION">
        <tr>
            <td colspan="5">
                <b>
                    <xsl:value-of select="TITLE"/>
                </b>
            </td>
            <td align="right">
                <!-- if we have only one MEAS and no other nodes, output result in summary column -->
                <xsl:if test="count(MEAS)=1 and count(SUMMARY)=0 and count(STEP)=0">
                    <b>
                        <xsl:apply-templates select="MEAS" mode="SINGLE"/>
                    </b>
                </xsl:if>
                <!-- if we have a summary, output result in summary column -->
                <xsl:if test="count(SUMMARY)=1">
                    <b>
                        <xsl:apply-templates select="SUMMARY" mode="SINGLE"/>
                    </b>
                </xsl:if>
            </td>
        </tr>
        <!-- expand all nodes if more than 1 MEAS or if CONDITIONING but not VISUAL_INSPECTION -->
        <xsl:if test="@OBJECT='CONDITIONING' or (@OBJECT!='VISUAL_INSPECTION' and count(MEAS)>1)">
            <xsl:apply-templates select="MEAS"/>
        </xsl:if>
        <!-- expand steps for OBD -->
        <xsl:if test="@OBJECT='OBD_CTRL'">
            <xsl:apply-templates select="MEAS"/>
            <xsl:apply-templates select="STEP" mode="OBD"/>
        </xsl:if>
        <!-- add a line if not last element -->
        <xsl:if test="position() != last()">
            <tr>
                <td colspan="{$Columns}">
                    <hr size="1"/>
                </td>
            </tr>
        </xsl:if>
    </xsl:template>
    <!--************************************************************************

  Process SECTION for gas blast
  Create new table row with title (span all columns except Ergebnis).

  ************************************************************************-->
    <xsl:template match="SECTION[@OBJECT='GAS_BLAST']">
        <tr>
            <td colspan="5">
                <b>
                    <xsl:value-of select="TITLE"/>
                </b>
            </td>
            <td align="right">
                <b>
                    <xsl:apply-templates select="SUMMARY" mode="SINGLE"/>
                </b>
            </td>
        </tr>
        <!-- ouput all MEAS nodes -->
        <xsl:apply-templates select="MEAS"/>
        <!-- create table header for gas blasts -->
        <tr>
            <td/>
            <td colspan="5">
                <hr size="1"/>
            </td>
        </tr>
        <tr>
            <th align="left" width="{$TitleW}">
                <xsl:value-of select="$GAS_BLAST"/>
            </th>
            <th align="right" width="{$UnitW}">
                <xsl:value-of select="$IDLE_SPEED"/>
            </th>
            <th align="right" width="{$MeasW}">
                <xsl:value-of select="$CUTOFF_SPEED"/>
            </th>
            <th align="right" width="{$MeasW}">
                <xsl:value-of select="$OPACITY"/>
            </th>
            <th align="right" width="{$MeasW}">
                <xsl:value-of select="$ACCEL_TIME"/>
            </th>
            <th align="right" width="{$ResW}">
                <xsl:value-of select="$Result"/>
            </th>
        </tr>
        <tr>
            <td/>
            <td align="right" width="{$UnitW}">
                <xsl:apply-templates select="STEP[1]/MEAS[@OBJECT='IDLE_SPEED']/VALUE/@UNIT"/>
            </td>
            <td align="right" width="{$MeasW}">
                <xsl:apply-templates select="STEP[1]/MEAS[@OBJECT='CUTOFF_SPEED']/VALUE/@UNIT"/>
            </td>
            <td align="right" width="{$MeasW}">
                <xsl:apply-templates select="STEP[1]/MEAS[@OBJECT='OPACITY']/VALUE/@UNIT"/>
            </td>
            <td align="right" width="{$MeasW}">
                <xsl:apply-templates select="STEP[1]/MEAS[@OBJECT='ACCEL_TIME']/VALUE/@UNIT"/>
            </td>
            <td/>
        </tr>
        <xsl:apply-templates select="STEP" mode="AU"/>
        <!-- add a line if not last element -->
        <xsl:if test="position() != last()">
            <tr>
                <td colspan="{$Columns}">
                    <hr size="1"/>
                </td>
            </tr>
        </xsl:if>
    </xsl:template>
    <!--********************************************************************

  Process STEP for OBD: output MEAS

  ********************************************************************-->
    <xsl:template match="STEP" mode="OBD">
        <!-- empty line -->
        <tr>
            <td colspan="{$Columns}">
                <br/>
            </td>
        </tr>
        <!-- single line if only one MEAS -->
        <tr>
            <td colspan="{$Columns - 1}">
                <b>
                    <xsl:value-of select="TITLE"/>
                </b>
            </td>
            <td align="right">
                <xsl:if test="count(MEAS) = 1">
                    <xsl:apply-templates select="MEAS" mode="SINGLE"/>
                </xsl:if>
            </td>
        </tr>
        <xsl:if test="count(MEAS) > 1">
            <xsl:apply-templates select="MEAS"/>
        </xsl:if>
    </xsl:template>
    <!--************************************************************************

  Process STEP for gas blasts, create table row with title and values

  ************************************************************************-->
    <xsl:template match="STEP" mode="AU">
        <tr>
            <td>
                <xsl:value-of select="@NO"/>
            </td>
            <td align="right">
                <xsl:value-of select="MEAS[@OBJECT='IDLE_SPEED']/VALUE"/>
            </td>
            <td align="right">
                <xsl:value-of select="MEAS[@OBJECT='CUTOFF_SPEED']/VALUE"/>
            </td>
            <td align="right">
                <xsl:value-of select="MEAS[@OBJECT='OPACITY']/VALUE"/>
            </td>
            <td align="right">
                <xsl:value-of select="MEAS[@OBJECT='ACCEL_TIME']/VALUE"/>
            </td>
            <td align="right">
                <xsl:apply-templates select="SUMMARY/MEAS/VALUE/@RESULT"/>
            </td>
        </tr>
    </xsl:template>
    <!--************************************************************************

  Process DEFECTS, span all columns except Ergebnis.

  ************************************************************************-->
    <xsl:template match="VALUE" mode="DEFECTS">
        <tr>
            <td colspan="{$Columns - 2}">
                <xsl:value-of select="../TITLE"/>
            </td>
            <td colspan="2" align="right">
                <xsl:value-of select="."/>
            </td>
        </tr>
    </xsl:template>
    <!--*********************************************************************-->
    <xsl:template match="SECTION[@OBJECT='DEFECTS']">
        <xsl:apply-templates select="MEAS/VALUE" mode="DEFECTS"/>
        <tr>
            <td colspan="{$Columns}">
                <hr size="1"/>
            </td>
        </tr>
    </xsl:template>
</xsl:stylesheet>
